@@ -6,6 +6,10 @@
 use v5.14;
 use warnings;
 
+package AtteanX::Endpoint {
+	our $VERSION	= "0.001_01";
+}
+
 package AtteanX::Error {
 	use Moo;
 	use Types::Standard qw(Str HashRef);
@@ -80,7 +84,7 @@ AtteanX::Endpoint - SPARQL 1.1 Protocol Endpoint
 
 =head1 VERSION
 
-This document describes AtteanX::Endpoint version 0.001
+This document describes AtteanX::Endpoint version 0.001_01
 
 =head1 SYNOPSIS
 
@@ -144,20 +148,17 @@ package AtteanX::Endpoint {
 	use File::ShareDir qw(dist_dir);
 	use HTTP::Negotiate qw(choose);
 	use IO::Compress::Gzip qw(gzip);
-	use HTML::HTML5::Parser;
 	use HTML::HTML5::Writer qw(DOCTYPE_XHTML_RDFA);
 	use Carp qw(croak);
 	use Types::Standard qw(ConsumerOf CodeRef HashRef ArrayRef Str Int);
 # 	use IO::Handle;
 # 	use Digest::MD5 qw(md5_base64);
-# 	use XML::LibXML 1.70;
+ 	use XML::LibXML 1.70;
 # 	use RDF::RDFa::Generator 0.102;
 # 	use Hash::Merge::Simple qw/ merge /;
 # 	use Fcntl qw(:flock SEEK_END);
 	use namespace::clean;
 
-	our $VERSION	= '0.000_01';
-
 	with 'MooX::Log::Any';
 
 	has 'planner' => (
@@ -456,7 +457,7 @@ END
 			my $stype		= 'text/html';
 			my $dir			= $ENV{ATTEAN_ENDPOINT_SHAREDIR} || File::Spec->catdir((eval { dist_dir('AtteanX-Endpoint') } || 'share'), 'endpoint');
 			my $template	= File::Spec->catfile($dir, 'index.html');
-			my $parser		= HTML::HTML5::Parser->new;
+			my $parser		= XML::LibXML->new(validation => 0, suppress_errors => 1, no_network => 1, recover => 2);
 			my $doc			= $parser->parse_file( $template );
 # 			my $gen			= RDF::RDFa::Generator->new( style => 'HTML::Head');
 # 			$gen->inject_document($doc, $sdmodel);
@@ -569,7 +570,7 @@ __END__
 =head1 BUGS
 
 Please report any bugs or feature requests to through the GitHub web interface
-at L<https://github.com/kasei/attean/issues>.
+at L<https://github.com/kasei/atteanx-endpoint/issues>.
 
 =head1 SEE ALSO
 
@@ -581,7 +582,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014 Gregory Todd Williams.
+Copyright (c) 2016 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
